// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { ArenaTournaments } from '../models/ArenaTournaments';
import { Ok } from '../models/Ok';
import { VariantKey } from '../models/VariantKey';

/**
 * no description
 */
export class ArenaTournamentsApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get team Arena tournaments
     * @param teamId ID of the team
     * @param max How many tournaments to download.
     */
    public async apiTeamArena(teamId: string, max?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'teamId' is not null or undefined
        if (teamId === null || teamId === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTeamArena", "teamId");
        }



        // Path Params
        const localVarPath = '/api/team/{teamId}/arena'
            .replace('{' + 'teamId' + '}', encodeURIComponent(String(teamId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (max !== undefined) {
            requestContext.setQueryParam("max", ObjectSerializer.serialize(max, "number", ""));
        }



        return requestContext;
    }

    /**
     * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
     * Get current tournaments
     */
    public async apiTournament(_options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // Path Params
        const localVarPath = '/api/tournament';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

    /**
     * Join an Arena tournament, possibly with a password and/or a team. 
     * Join an Arena tournament
     * @param id The tournament ID.
     * @param password The tournament password, if one is required
     * @param team The team to join the tournament with, for team battle tournaments
     */
    public async apiTournamentJoin(id: string, password?: string, team?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentJoin", "id");
        }




        // Path Params
        const localVarPath = '/api/tournament/{id}/join'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (password !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('password', password as any);
        }
        if (team !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('team', team as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Create a public or private Arena tournament.  This endpoint mirrors the form on <https://lichess.org/tournament/new>.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the `teambBattleByTeam` argument. 
     * Create a new Arena tournament
     * @param clockTime Clock initial time in minutes
     * @param clockIncrement Clock increment in seconds
     * @param minutes How long the tournament lasts, in minutes
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @param variant 
     * @param rated Games are rated and impact players ratings
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @param berserkable Whether the players can use berserk
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
     * @param hasChat Whether the players can discuss in a chat
     * @param description Anything you want to tell players about the tournament
     * @param password Make the tournament private, and restrict access with a password
     * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
     * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead. 
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament.
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join.
     */
    public async apiTournamentPost(clockTime: number, clockIncrement: number, minutes: number, name?: string, waitMinutes?: number, startDate?: number, variant?: VariantKey, rated?: boolean, position?: string, berserkable?: boolean, streakable?: boolean, hasChat?: boolean, description?: string, password?: string, teambBattleByTeam?: string, conditionsTeamMemberTeamId?: string, conditionsMinRatingRating?: number, conditionsMaxRatingRating?: number, conditionsNbRatedGameNb?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'clockTime' is not null or undefined
        if (clockTime === null || clockTime === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentPost", "clockTime");
        }


        // verify required parameter 'clockIncrement' is not null or undefined
        if (clockIncrement === null || clockIncrement === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentPost", "clockIncrement");
        }


        // verify required parameter 'minutes' is not null or undefined
        if (minutes === null || minutes === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentPost", "minutes");
        }


















        // Path Params
        const localVarPath = '/api/tournament';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (name !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('name', name as any);
        }
        if (clockTime !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clockTime', clockTime as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clockIncrement', clockIncrement as any);
        }
        if (minutes !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('minutes', minutes as any);
        }
        if (waitMinutes !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('waitMinutes', waitMinutes as any);
        }
        if (startDate !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('startDate', startDate as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (position !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('position', position as any);
        }
        if (berserkable !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('berserkable', berserkable as any);
        }
        if (streakable !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('streakable', streakable as any);
        }
        if (hasChat !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('hasChat', hasChat as any);
        }
        if (description !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('description', description as any);
        }
        if (password !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('password', password as any);
        }
        if (teambBattleByTeam !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('teambBattleByTeam', teambBattleByTeam as any);
        }
        if (conditionsTeamMemberTeamId !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.teamMember.teamId', conditionsTeamMemberTeamId as any);
        }
        if (conditionsMinRatingRating !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.minRating.rating', conditionsMinRatingRating as any);
        }
        if (conditionsMaxRatingRating !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.maxRating.rating', conditionsMaxRatingRating as any);
        }
        if (conditionsNbRatedGameNb !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.nbRatedGame.nb', conditionsNbRatedGameNb as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
     * Update a team battle
     * @param id The tournament ID (8 characters)..
     * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60; 
     * @param nbLeaders Number team leaders per team.
     */
    public async apiTournamentTeamBattlePost(id: string, teams: string, nbLeaders: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentTeamBattlePost", "id");
        }


        // verify required parameter 'teams' is not null or undefined
        if (teams === null || teams === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentTeamBattlePost", "teams");
        }


        // verify required parameter 'nbLeaders' is not null or undefined
        if (nbLeaders === null || nbLeaders === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentTeamBattlePost", "nbLeaders");
        }


        // Path Params
        const localVarPath = '/api/tournament/team-battle/{id}'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (teams !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('teams', teams as any);
        }
        if (nbLeaders !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('nbLeaders', nbLeaders as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Terminate an Arena tournament 
     * Terminate an Arena tournament
     * @param id The tournament ID.
     */
    public async apiTournamentTerminate(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentTerminate", "id");
        }


        // Path Params
        const localVarPath = '/api/tournament/{id}/terminate'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
     * Update an Arena tournament
     * @param id The tournament ID.
     * @param clockTime Clock initial time in minutes
     * @param clockIncrement Clock increment in seconds
     * @param minutes How long the tournament lasts, in minutes
     * @param name The tournament name. Leave empty to get a random Grandmaster name
     * @param waitMinutes How long to wait before starting the tournament, from now, in minutes
     * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting
     * @param variant 
     * @param rated Games are rated and impact players ratings
     * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
     * @param berserkable Whether the players can use berserk
     * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2.
     * @param hasChat Whether the players can discuss in a chat
     * @param description Anything you want to tell players about the tournament
     * @param password Make the tournament private, and restrict access with a password
     * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament.
     * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
     * @param conditionsNbRatedGameNb Minimum number of rated games required to join.
     */
    public async apiTournamentUpdate(id: string, clockTime: number, clockIncrement: number, minutes: number, name?: string, waitMinutes?: number, startDate?: number, variant?: VariantKey, rated?: boolean, position?: string, berserkable?: boolean, streakable?: boolean, hasChat?: boolean, description?: string, password?: string, conditionsMinRatingRating?: number, conditionsMaxRatingRating?: number, conditionsNbRatedGameNb?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentUpdate", "id");
        }


        // verify required parameter 'clockTime' is not null or undefined
        if (clockTime === null || clockTime === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentUpdate", "clockTime");
        }


        // verify required parameter 'clockIncrement' is not null or undefined
        if (clockIncrement === null || clockIncrement === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentUpdate", "clockIncrement");
        }


        // verify required parameter 'minutes' is not null or undefined
        if (minutes === null || minutes === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentUpdate", "minutes");
        }
















        // Path Params
        const localVarPath = '/api/tournament/{id}'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (name !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('name', name as any);
        }
        if (clockTime !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clockTime', clockTime as any);
        }
        if (clockIncrement !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('clockIncrement', clockIncrement as any);
        }
        if (minutes !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('minutes', minutes as any);
        }
        if (waitMinutes !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('waitMinutes', waitMinutes as any);
        }
        if (startDate !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('startDate', startDate as any);
        }
        if (variant !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('variant', variant as any);
        }
        if (rated !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('rated', rated as any);
        }
        if (position !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('position', position as any);
        }
        if (berserkable !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('berserkable', berserkable as any);
        }
        if (streakable !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('streakable', streakable as any);
        }
        if (hasChat !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('hasChat', hasChat as any);
        }
        if (description !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('description', description as any);
        }
        if (password !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('password', password as any);
        }
        if (conditionsMinRatingRating !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.minRating.rating', conditionsMinRatingRating as any);
        }
        if (conditionsMaxRatingRating !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.maxRating.rating', conditionsMaxRatingRating as any);
        }
        if (conditionsNbRatedGameNb !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('conditions.nbRatedGame.nb', conditionsNbRatedGameNb as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It's possible to join again later. Points and streaks are preserved. 
     * Pause of leave an Arena tournament
     * @param id The tournament ID.
     */
    public async apiTournamentWithdraw(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiTournamentWithdraw", "id");
        }


        // Path Params
        const localVarPath = '/api/tournament/{id}/withdraw'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
     * Get tournaments created by a user
     * @param username The user whose created tournaments to fetch
     * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60; 
     */
    public async apiUserNameTournamentCreated(username: string, status?: 10 | 20 | 30, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'username' is not null or undefined
        if (username === null || username === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "apiUserNameTournamentCreated", "username");
        }



        // Path Params
        const localVarPath = '/api/user/{username}/tournament/created'
            .replace('{' + 'username' + '}', encodeURIComponent(String(username)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (status !== undefined) {
            requestContext.setQueryParam("status", ObjectSerializer.serialize(status, "10 | 20 | 30", ""));
        }



        return requestContext;
    }

    /**
     * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
     * Export games of an Arena tournament
     * @param id The tournament ID.
     * @param player Only games of a particular player. Leave empty to fetch games of all players.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     */
    public async gamesByTournament(id: string, player?: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "gamesByTournament", "id");
        }









        // Path Params
        const localVarPath = '/api/tournament/{id}/games'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (player !== undefined) {
            requestContext.setQueryParam("player", ObjectSerializer.serialize(player, "string", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }



        return requestContext;
    }

    /**
     * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
     * Get results of an Arena tournament
     * @param id The tournament ID.
     * @param nb Max number of players to fetch
     */
    public async resultsByTournament(id: string, nb?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "resultsByTournament", "id");
        }



        // Path Params
        const localVarPath = '/api/tournament/{id}/results'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (nb !== undefined) {
            requestContext.setQueryParam("nb", ObjectSerializer.serialize(nb, "number", ""));
        }



        return requestContext;
    }

    /**
     * Teams of a team battle tournament, with top players, sorted by rank (best first). 
     * Get team standing of a team battle
     * @param id The tournament ID.
     */
    public async teamsByTournament(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "teamsByTournament", "id");
        }


        // Path Params
        const localVarPath = '/api/tournament/{id}/teams'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

    /**
     * Get detailed info about recently finished, current, or upcoming tournament's duels, player standings, and other info. 
     * Get info about an Arena tournament
     * @param id The tournament ID.
     * @param page Specify which page of player standings to view.
     */
    public async tournament(id: string, page?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("ArenaTournamentsApi", "tournament", "id");
        }



        // Path Params
        const localVarPath = '/api/tournament/{id}'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (page !== undefined) {
            requestContext.setQueryParam("page", ObjectSerializer.serialize(page, "number", ""));
        }



        return requestContext;
    }

}

export class ArenaTournamentsApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTeamArena
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTeamArena(response: ResponseContext): Promise<Array<any> > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Array<any> = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Array<any>", ""
            ) as Array<any>;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Array<any> = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Array<any>", ""
            ) as Array<any>;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournament
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournament(response: ResponseContext): Promise<ArenaTournaments > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: ArenaTournaments = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ArenaTournaments", ""
            ) as ArenaTournaments;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: ArenaTournaments = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "ArenaTournaments", ""
            ) as ArenaTournaments;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentJoin
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentJoin(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Joining the tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentPost
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentPost(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The creation of the Arena tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentTeamBattlePost
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentTeamBattlePost(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The update of the team battle tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentTerminate
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentTerminate(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Terminating the tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentUpdate
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentUpdate(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "The update of the Arena tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiTournamentWithdraw
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiTournamentWithdraw(response: ResponseContext): Promise<Ok > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }
        if (isCodeInRange("400", response.httpStatusCode)) {
            const body: Error = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Error", ""
            ) as Error;
            throw new ApiException<Error>(400, "Pausing/leaving the tournament failed.", body, response.headers);
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: Ok = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "Ok", ""
            ) as Ok;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiUserNameTournamentCreated
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiUserNameTournamentCreated(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gamesByTournament
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gamesByTournament(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to resultsByTournament
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async resultsByTournament(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to teamsByTournament
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async teamsByTournament(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to tournament
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async tournament(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
