// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';


import { PerfType } from '../models/PerfType';

/**
 * no description
 */
export class GamesApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 
     * Get my ongoing games
     * @param nb Max number of games to fetch
     */
    public async apiAccountPlaying(nb?: number, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;


        // Path Params
        const localVarPath = '/api/account/playing';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (nb !== undefined) {
            requestContext.setQueryParam("nb", ObjectSerializer.serialize(nb, "number", ""));
        }


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. <https://lichess.org/@/german11> for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 
     * Export games of a user
     * @param username The user name.
     * @param since Download games played since this timestamp.
     * @param until Download games played until this timestamp.
     * @param max How many games to download. Leave empty to download all games.
     * @param vs [Filter] Only games played against this opponent
     * @param rated [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games
     * @param perfType [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
     * @param color [Filter] Only games played as this color.
     * @param analysed [Filter] Only games with or without a computer analysis available
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param ongoing Include ongoing games. The last 3 moves will be omitted.
     * @param finished Include finished games. Set to &#x60;false&#x60; to only get ongoing games.
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     * @param sort Sort order of the games.
     */
    public async apiGamesUser(username: string, since?: number, until?: number, max?: number, vs?: string, rated?: boolean, perfType?: PerfType, color?: 'white' | 'black', analysed?: boolean, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, ongoing?: boolean, finished?: boolean, players?: string, sort?: 'dateAsc' | 'dateDesc', _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'username' is not null or undefined
        if (username === null || username === undefined) {
            throw new RequiredError("GamesApi", "apiGamesUser", "username");
        }




















        // Path Params
        const localVarPath = '/api/games/user/{username}'
            .replace('{' + 'username' + '}', encodeURIComponent(String(username)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (since !== undefined) {
            requestContext.setQueryParam("since", ObjectSerializer.serialize(since, "number", ""));
        }

        // Query Params
        if (until !== undefined) {
            requestContext.setQueryParam("until", ObjectSerializer.serialize(until, "number", ""));
        }

        // Query Params
        if (max !== undefined) {
            requestContext.setQueryParam("max", ObjectSerializer.serialize(max, "number", ""));
        }

        // Query Params
        if (vs !== undefined) {
            requestContext.setQueryParam("vs", ObjectSerializer.serialize(vs, "string", ""));
        }

        // Query Params
        if (rated !== undefined) {
            requestContext.setQueryParam("rated", ObjectSerializer.serialize(rated, "boolean", ""));
        }

        // Query Params
        if (perfType !== undefined) {
            requestContext.setQueryParam("perfType", ObjectSerializer.serialize(perfType, "PerfType", ""));
        }

        // Query Params
        if (color !== undefined) {
            requestContext.setQueryParam("color", ObjectSerializer.serialize(color, "'white' | 'black'", ""));
        }

        // Query Params
        if (analysed !== undefined) {
            requestContext.setQueryParam("analysed", ObjectSerializer.serialize(analysed, "boolean", ""));
        }

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }

        // Query Params
        if (ongoing !== undefined) {
            requestContext.setQueryParam("ongoing", ObjectSerializer.serialize(ongoing, "boolean", ""));
        }

        // Query Params
        if (finished !== undefined) {
            requestContext.setQueryParam("finished", ObjectSerializer.serialize(finished, "boolean", ""));
        }

        // Query Params
        if (players !== undefined) {
            requestContext.setQueryParam("players", ObjectSerializer.serialize(players, "string", ""));
        }

        // Query Params
        if (sort !== undefined) {
            requestContext.setQueryParam("sort", ObjectSerializer.serialize(sort, "'dateAsc' | 'dateDesc'", ""));
        }


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 
     * Export ongoing game of a user
     * @param username 
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public async apiUserCurrentGame(username: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, literate?: boolean, players?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'username' is not null or undefined
        if (username === null || username === undefined) {
            throw new RequiredError("GamesApi", "apiUserCurrentGame", "username");
        }










        // Path Params
        const localVarPath = '/api/user/{username}/current-game'
            .replace('{' + 'username' + '}', encodeURIComponent(String(username)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }

        // Query Params
        if (literate !== undefined) {
            requestContext.setQueryParam("literate", ObjectSerializer.serialize(literate, "boolean", ""));
        }

        // Query Params
        if (players !== undefined) {
            requestContext.setQueryParam("players", ObjectSerializer.serialize(players, "string", ""));
        }



        return requestContext;
    }

    /**
     * Import a game from PGN. See <https://lichess.org/paste>.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 
     * Import one game
     * @param pgn The PGN. It can contain only one game. Most standard tags are supported.
     */
    public async gameImport(pgn?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;


        // Path Params
        const localVarPath = '/api/import';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Form Params
        const useForm = canConsumeForm([
            'application/x-www-form-urlencoded',
        ]);

        let localVarFormParams
        if (useForm) {
            localVarFormParams = new FormData();
        } else {
            localVarFormParams = new URLSearchParams();
        }

        if (pgn !== undefined) {
             // TODO: replace .append with .set
             localVarFormParams.append('pgn', pgn as any);
        }

        requestContext.setBody(localVarFormParams);

        if(!useForm) {
            const contentType = ObjectSerializer.getPreferredMediaType([
                "application/x-www-form-urlencoded"
            ]);
            requestContext.setHeaderParam("Content-Type", contentType);
        }

        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

    /**
     * Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export one game
     * @param gameId The game ID (8 characters).
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public async gamePgn(gameId: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, literate?: boolean, players?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'gameId' is not null or undefined
        if (gameId === null || gameId === undefined) {
            throw new RequiredError("GamesApi", "gamePgn", "gameId");
        }










        // Path Params
        const localVarPath = '/game/export/{gameId}'
            .replace('{' + 'gameId' + '}', encodeURIComponent(String(gameId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }

        // Query Params
        if (literate !== undefined) {
            requestContext.setQueryParam("literate", ObjectSerializer.serialize(literate, "boolean", ""));
        }

        // Query Params
        if (players !== undefined) {
            requestContext.setQueryParam("players", ObjectSerializer.serialize(players, "string", ""));
        }



        return requestContext;
    }

    /**
     * Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the `withCurrentGames` flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is `POST` so a longer list of IDs can be sent in the request body. 
     * Stream games of users
     * @param body Up to 300 user IDs separated by commas.
     * @param withCurrentGames Include the already started games at the beginning of the stream.
     */
    public async gamesByUsers(body: string, withCurrentGames?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'body' is not null or undefined
        if (body === null || body === undefined) {
            throw new RequiredError("GamesApi", "gamesByUsers", "body");
        }



        // Path Params
        const localVarPath = '/api/stream/games-by-users';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (withCurrentGames !== undefined) {
            requestContext.setQueryParam("withCurrentGames", ObjectSerializer.serialize(withCurrentGames, "boolean", ""));
        }


        // Body Params
        const contentType = ObjectSerializer.getPreferredMediaType([
            "text/plain"
        ]);
        requestContext.setHeaderParam("Content-Type", contentType);
        const serializedBody = ObjectSerializer.stringify(
            ObjectSerializer.serialize(body, "string", ""),
            contentType
        );
        requestContext.setBody(serializedBody);


        return requestContext;
    }

    /**
     * Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is `POST` so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 
     * Export games by IDs
     * @param body Game IDs separated by commas. Up to 300.
     * @param moves Include the PGN moves.
     * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field.
     * @param tags Include the PGN tags.
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60; 
     * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60; 
     * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt; 
     */
    public async gamesExportIds(body: string, moves?: boolean, pgnInJson?: boolean, tags?: boolean, clocks?: boolean, evals?: boolean, opening?: boolean, players?: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'body' is not null or undefined
        if (body === null || body === undefined) {
            throw new RequiredError("GamesApi", "gamesExportIds", "body");
        }









        // Path Params
        const localVarPath = '/games/export/_ids';

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.POST);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (moves !== undefined) {
            requestContext.setQueryParam("moves", ObjectSerializer.serialize(moves, "boolean", ""));
        }

        // Query Params
        if (pgnInJson !== undefined) {
            requestContext.setQueryParam("pgnInJson", ObjectSerializer.serialize(pgnInJson, "boolean", ""));
        }

        // Query Params
        if (tags !== undefined) {
            requestContext.setQueryParam("tags", ObjectSerializer.serialize(tags, "boolean", ""));
        }

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (evals !== undefined) {
            requestContext.setQueryParam("evals", ObjectSerializer.serialize(evals, "boolean", ""));
        }

        // Query Params
        if (opening !== undefined) {
            requestContext.setQueryParam("opening", ObjectSerializer.serialize(opening, "boolean", ""));
        }

        // Query Params
        if (players !== undefined) {
            requestContext.setQueryParam("players", ObjectSerializer.serialize(players, "string", ""));
        }


        // Body Params
        const contentType = ObjectSerializer.getPreferredMediaType([
            "text/plain"
        ]);
        requestContext.setHeaderParam("Content-Type", contentType);
        const serializedBody = ObjectSerializer.stringify(
            ObjectSerializer.serialize(body, "string", ""),
            contentType
        );
        requestContext.setBody(serializedBody);


        return requestContext;
    }

    /**
     * Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 
     * Stream moves of a game
     * @param id 
     */
    public async streamGame(id: string, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'id' is not null or undefined
        if (id === null || id === undefined) {
            throw new RequiredError("GamesApi", "streamGame", "id");
        }


        // Path Params
        const localVarPath = '/api/stream/game/{id}'
            .replace('{' + 'id' + '}', encodeURIComponent(String(id)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")



        return requestContext;
    }

}

export class GamesApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiAccountPlaying
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiAccountPlaying(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiGamesUser
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiGamesUser(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to apiUserCurrentGame
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async apiUserCurrentGame(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gameImport
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gameImport(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gamePgn
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gamePgn(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gamesByUsers
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gamesByUsers(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to gamesExportIds
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async gamesExportIds(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to streamGame
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async streamGame(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
