// TODO: better import syntax?
import { BaseAPIRequestFactory, RequiredError } from './baseapi';
import {Configuration} from '../configuration';
import { RequestContext, HttpMethod, ResponseContext, HttpFile} from '../http/http';
import {ObjectSerializer} from '../models/ObjectSerializer';
import {ApiException} from './exception';
import {canConsumeForm, isCodeInRange} from '../util';



/**
 * no description
 */
export class StudiesApiRequestFactory extends BaseAPIRequestFactory {

    /**
     * Download all chapters of a study in PGN format. 
     * Export all chapters
     * @param studyId The study ID (8 characters).
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public async studyAllChaptersPgn(studyId: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'studyId' is not null or undefined
        if (studyId === null || studyId === undefined) {
            throw new RequiredError("StudiesApi", "studyAllChaptersPgn", "studyId");
        }





        // Path Params
        const localVarPath = '/api/study/{studyId}.pgn'
            .replace('{' + 'studyId' + '}', encodeURIComponent(String(studyId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (comments !== undefined) {
            requestContext.setQueryParam("comments", ObjectSerializer.serialize(comments, "boolean", ""));
        }

        // Query Params
        if (variations !== undefined) {
            requestContext.setQueryParam("variations", ObjectSerializer.serialize(variations, "boolean", ""));
        }



        return requestContext;
    }

    /**
     * Download one study chapter in PGN format. 
     * Export one study chapter
     * @param studyId The study ID (8 characters).
     * @param chapterId The chapter ID (8 characters).
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public async studyChapterPgn(studyId: string, chapterId: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'studyId' is not null or undefined
        if (studyId === null || studyId === undefined) {
            throw new RequiredError("StudiesApi", "studyChapterPgn", "studyId");
        }


        // verify required parameter 'chapterId' is not null or undefined
        if (chapterId === null || chapterId === undefined) {
            throw new RequiredError("StudiesApi", "studyChapterPgn", "chapterId");
        }





        // Path Params
        const localVarPath = '/study/{studyId}/{chapterId}.pgn'
            .replace('{' + 'studyId' + '}', encodeURIComponent(String(studyId)))
            .replace('{' + 'chapterId' + '}', encodeURIComponent(String(chapterId)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (comments !== undefined) {
            requestContext.setQueryParam("comments", ObjectSerializer.serialize(comments, "boolean", ""));
        }

        // Query Params
        if (variations !== undefined) {
            requestContext.setQueryParam("variations", ObjectSerializer.serialize(variations, "boolean", ""));
        }



        return requestContext;
    }

    /**
     * Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 
     * Export all studies of a user
     * @param username The user whose studies we export
     * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60; 
     * @param comments Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60; 
     * @param variations Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60; 
     */
    public async studyExportAllPgn(username: string, clocks?: boolean, comments?: boolean, variations?: boolean, _options?: Configuration): Promise<RequestContext> {
        let _config = _options || this.configuration;

        // verify required parameter 'username' is not null or undefined
        if (username === null || username === undefined) {
            throw new RequiredError("StudiesApi", "studyExportAllPgn", "username");
        }





        // Path Params
        const localVarPath = '/study/by/{username}/export.pgn'
            .replace('{' + 'username' + '}', encodeURIComponent(String(username)));

        // Make Request Context
        const requestContext = _config.baseServer.makeRequestContext(localVarPath, HttpMethod.GET);
        requestContext.setHeaderParam("Accept", "application/json, */*;q=0.8")

        // Query Params
        if (clocks !== undefined) {
            requestContext.setQueryParam("clocks", ObjectSerializer.serialize(clocks, "boolean", ""));
        }

        // Query Params
        if (comments !== undefined) {
            requestContext.setQueryParam("comments", ObjectSerializer.serialize(comments, "boolean", ""));
        }

        // Query Params
        if (variations !== undefined) {
            requestContext.setQueryParam("variations", ObjectSerializer.serialize(variations, "boolean", ""));
        }


        let authMethod = null;
        // Apply auth methods
        authMethod = _config.authMethods["OAuth2"]
        if (authMethod) {
            await authMethod.applySecurityAuthentication(requestContext);
        }

        return requestContext;
    }

}

export class StudiesApiResponseProcessor {

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to studyAllChaptersPgn
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async studyAllChaptersPgn(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to studyChapterPgn
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async studyChapterPgn(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

    /**
     * Unwraps the actual response sent by the server from the response context and deserializes the response content
     * to the expected objects
     *
     * @params response Response returned by the server for a request to studyExportAllPgn
     * @throws ApiException if the response code was not in [200, 299]
     */
     public async studyExportAllPgn(response: ResponseContext): Promise<any > {
        const contentType = ObjectSerializer.normalizeMediaType(response.headers["content-type"]);
        if (isCodeInRange("200", response.httpStatusCode)) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        // Work around for missing responses in specification, e.g. for petstore.yaml
        if (response.httpStatusCode >= 200 && response.httpStatusCode <= 299) {
            const body: any = ObjectSerializer.deserialize(
                ObjectSerializer.parse(await response.body.text(), contentType),
                "any", ""
            ) as any;
            return body;
        }

        throw new ApiException<string | Blob | undefined>(response.httpStatusCode, "Unknown API Status Code!", await response.getBodyAsAny(), response.headers);
    }

}
